@@ -1,20 +1,21 @@
 import re
 import platform
 from aiebash.logger import log_execution_time
+from aiebash.i18n import t
 
 
-@log_execution_time
 def format_api_key_display(api_key: str) -> str:
-    """Форматирует отображение API ключа для логирования"""
+    """Форматирует отображение API ключа для логирования
+    показывает первые и последние 5 символов, остальное заменяет на "...".
+    """
     if not api_key:
-        return "(не задан)"
+        return t("(not set)")
     elif len(api_key) <= 10:
         return api_key
     else:
         return f"{api_key[:5]}...{api_key[-5:]}"
 
 
-@log_execution_time
 def extract_labeled_code_blocks(text: str) -> list[str]:
     """
     Извлекает содержимое блоков кода, у которых сверху есть подпись в квадратных скобках.
